const int n_lights = 0;
struct LightParams
{
	vec3 direction;
	vec3 color;
};
uniform LightParams lights[n_lights];
uniform vec3 ambient;
uniform mat4 model_matrix;
uniform mat4 vp_matrix;

#pragma MSP stage(vertex)
layout(location=0) in vec4 position;
layout(location=1) in vec3 normal;
void main()
{
	out vec3 world_normal = mat3(model_matrix)*normal;
	gl_Position = vp_matrix*model_matrix*position;
}

#pragma MSP stage(fragment)
layout(location=0) out vec4 frag_color;
void main()
{
	vec3 color = ambient;
	for(int i=0; i<n_lights; ++i)
		color += max(dot(normalize(world_normal), lights[i].direction), 0.0)*lights[i].color;
	frag_color = vec4(color, 1.0);
}

/* Expected output: vertex
uniform mat4 model_matrix;
uniform mat4 vp_matrix;
layout(location=0) in vec4 position;
void main()
{
  gl_Position = vp_matrix*model_matrix*position;
}
*/

/* Expected output: fragment
uniform vec3 ambient;
layout(location=0) out vec4 frag_color;
void main()
{
  frag_color = vec4(ambient, 1.0);
}
*/
